#! /bin/sh
#+
#
# .. program:: cresamsu.sh
#
# .. _cresamsu.sh:
#
# ===========
# cresamsu.sh
# ===========
#
# SYNOPSIS
# ========
#
# ::
#
#  $ cresamsu.sh -b yyyymmdd -e yyyymmdd -lonmin lonmin -lonmax lonmax -latmin latmin -latmax latmax -numch numch -temp temp -rtemp rtemp -rhdeg rhdeg
#
# DESCRIPTION
# ===========
#
# +todo+
#
# .. option:: -b beginning date <yyyymmdd>
# .. option:: -e end date <yyyymmdd>
# .. option:: -lonmin <lonmin>
# .. option:: -lonmax <lonmax>
# .. option:: -latmin <latmin>
# .. option:: -latmax <latmax>
# .. option:: -numch <channel>
# .. option:: -temp <temp>
# .. option:: -rtemp <rtemp>
# .. option:: -rhdeg <rhdeg>
#
# ``cresamsu.sh`` read 
# :file:`${PROJECT_ID}/AMSU/{yyyy}/{mm}/{numch}_{yyyymmdd}_{geomin}_{geomax}_nadir.dat`
# for each yyyymmdd between datemin and datemax (:option:`-b` and :option:`-e`).
#
# ``cresamsu.sh`` write
# :file:`${PROJECT_ID}/AMSU/{numch}{temp}rt{rtemp}rh{rhdeg}_{yyyymmdd}_{yyyymmdd}_{geomin}_{geomax}_03150e4150n.nc`
#
# :func:`cresamsu` is launched here using ${IDL_CMD} command
# (see :ref:`varamma_profile.sh` to know how to set this environnement variable).
#
# +todo+
#
# Log file is written on
# :file:`${PROJECT_LOG}/cresamsu.log.{YYYYMMDDTHHMMSSZ}`
#
# .. only:: man
#
#    Figure is visible on PDF and HTML documents only.
#
# .. only:: html or latex
#
#     .. graphviz::
#
#        digraph cresamsu {
#
#           amsu_t2 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax.dat"];
#           amsu_t3 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.dat"];
#
#           log [shape=ellipse,fontname=Courier,label="${PROJECT_LOG}/cresamsu.log{YYYYMMDDTHHMMSSZ}"];
#
#           cresamsu [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/cresamsu.sh",
#           label="${PROJECT}/src/cresamsu.sh"];
#
#           {amsu_t2} -> {cresamsu} -> {log amsu_t5}
#
#         }
#
# EXAMPLES
# ========
#
# You already used :ref:`traite_amsuab.sh` to process AMSU channel a5 data
# during [20060801, 20060802[ and you want to run cressman filter and produce 
# NetCDF files::
#
#   cresamsu.sh -b 20060801 -e 20060802 -lonmin -25 -lonmax 25 -latmin -5 -latmax 20 -numch a5 -temp 'm' -rtemp 1. -rhdeg .5
#
# And look at log file with ::
#
#   tlogd.sh cresamsu
#
# A more realistic example::
#
#   cresamsu.sh -b 20060101 -e 20060630 -lonmin -32 -lonmax 32 -latmin -2 -latmax 42 -temp 'm' -rtemp 1. -rhdeg .5
#
# and of course on files in ${PROJECT_ID}.
#
# SEE ALSO
# ========
#
# :ref:`varamma_profile.sh`
# :ref:`project_init.pro`
#
# :ref:`run_cresamsu.sh` to submit job
#
# Previous step : :ref:`traite_amsuab.sh`
#
# Use :
# :func:`cresamsu`
#
# .. todo::
#
# TODO
# ====
#
# get rid of "Program caused arithmetic error: Floating illegal operand"
#
# build/complete catalog
#
# adjust yyyymmddb_min and yyyymmdde_max
#
# idl status = 0 even if not ok
#
# handle -f option
#
# test if demo mode idl (or force cancel if demo)
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - fplod 20120430
# 
#   * cresamsu is now a function
#   * creation
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
     echo "${command} : www : no specific posix checking"
     date_cmd=date
   ;;
   Darwin)
     set -o posix
     date_cmd=gdate
   ;;
   Linux)
     set -o posix
     date_cmd=date
   ;;
   *)
    set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
# get current time at the beginning of the process
timebd="$(date +%s)"
#
usage=" Usage : ${command} [-f] -b yyyymmdd -e yyyymmdd -lonmin lonmin -lonmax lonmax -latmin latmin -latmax latmax -numch numch -temp temp -rtemp rtemp -rhdeg rhdeg"
#
hostname=$(hostname)
#
yyyymmddb_min=20000101
yyyymmdde_max=20121231
#
# default
debug=0
force=0
yyyymmddb=20060420
yyyymmdde=20060420
#
minargcount=18
if [ ${#} -lt ${minargcount} ]
then
   echo "${command} : eee : not enought arguments (${#} vs ${minargcount})"
   echo "${usage}"
   exit 1
fi
unset minargcount
#
while [ ${#} -gt 0 ]
do
   case ${1} in
     -b)
        # first date to get
        yyyymmddb=${2}
        shift
     ;;
     -e)
        # last date to get
        yyyymmdde=${2}
        shift
     ;;
     -lonmin)
        lonmin=${2}
        shift
     ;;
     -lonmax)
        lonmax=${2}
        shift
     ;;
     -latmin)
        latmin=${2}
        shift
     ;;
     -latmax)
        latmax=${2}
        shift
     ;;
     -numch)
        numch=${2}
        shift
     ;;
     -temp)
        temp=${2}
        shift
     ;;
     -rtemp)
        rtemp=${2}
        shift
     ;;
     -rhdeg)
        rhdeg=${2}
        shift
     ;;
     -f)
        force=1
     ;;
     -h)
        echo "${usage}"
        exit 0
     ;;
     *)
        # other choice
        echo "${command} : eee : unknown option ${1}"
        echo "${usage}"
        exit 1
     ;;
   esac
   # next flag
   shift
done
unset usage
#
# check parameters
# and define associated variables
${date_cmd} -d "${yyyymmddb}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
    echo "${command} : eee : yyyymmddb ${yyyymmddb} argument invalid"
    exit 1
fi
unset status_date
#
d=$((${yyyymmddb} - ${yyyymmddb_min}))
if [ ${d} -lt 0 ] 
then
    echo "${command} : eee : yyyymmddb ${yyyymmddb} must be equal or greater than yyyymmddb_min ${yyyymmddb_min}"
    exit 1
fi
unset d
#
d=$((${yyyymmddb} - ${yyyymmdde_max}))
if [ ${d} -gt 0 ] 
then
    echo "${command} : eee : yyyymmddb ${yyyymmddb} must be equal or lower than yyyymmdde_max ${yyyymmdde_max}"
    exit 1
fi
unset d
#
${date_cmd} -d "${yyyymmdde}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
    echo "${command} : eee : yyyymmdde ${yyyymmdde} argument invalid"
    exit 1
fi
unset status_date
#
d=$((${yyyymmdde} - ${yyyymmdde_max}))
if [ ${d} -gt 0 ] 
then
    echo "${command} : eee : yyyymmdde ${yyyymmdde} must be lower or equal to yyyymmdde_max ${yyyymmdde_max}"
    exit 1
fi
unset d
#
if [[ "${yyyymmdde}" < "${yyyymmddb}" ]]
then
    echo "${command} : eee : yyyymmdde ${yyyymmdde} must be greater than yyyymmddb ${yyyymmddb}"
    exit 1
fi
#
if [[ "${yyyymmdde}" = "${yyyymmddb}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be greater than yyyymmddb ${yyyymmddb}"
     exit 1
fi
#
tool=${IDL_CMD}
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : tool ${IDL_CMD} not found"
   echo "${command} : eee : check varamma_profile.sh sequence"
   exit 1
fi
unset status
unset tool
#
# check for write permission on PROJECT_LOG
if [ ! -w ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not writable"
   exit 1
fi
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
echo "IDL_CMD=${IDL_CMD}" 1>> ${log}
unset log_date
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "yyyymmddb=${yyyymmddb}" 1>> ${log}
echo "yyyymmdde=${yyyymmdde}" 1>> ${log}
echo "lonmin=${lonmin}" 1>> ${log}
echo "lonmax=${lonmax}" 1>> ${log}
echo "latmin=${latmin}" 1>> ${log}
echo "latmax=${latmax}" 1>> ${log}
echo "numch=${numch}"  1>> ${log}
echo "temp=${temp}"  1>> ${log}
echo "rtemp=${rtemp}"  1>> ${log}
echo "rhdeg=${rhdeg}"  1>> ${log}
echo "" 1>> ${log}
#
datesec=$(${date_cmd} -u -d "${yyyymmddb}" +%s | awk '{printf "%10.10d",$1}')
yyyyb=$(${date_cmd} -u -d "1970-01-01 ${datesec} sec" +%Y)
mmb=$(${date_cmd} -u -d "1970-01-01 ${datesec} sec" +%m)
ddb=$(${date_cmd} -u -d "1970-01-01 ${datesec} sec" +%d)
unset datesec
unset yyyymmddb
#
datesec=$(${date_cmd} -u -d "${yyyymmdde}" +%s | awk '{printf "%10.10d",$1}')
yyyye=$(${date_cmd} -u -d "1970-01-01 ${datesec} sec" +%Y)
mme=$(${date_cmd} -u -d "1970-01-01 ${datesec} sec" +%m)
dde=$(${date_cmd} -u -d "1970-01-01 ${datesec} sec" +%d)
unset datesec
unset yyyymmdde
#
cat >> ${PROJECT}/src/cresamsu_${$}.pro << EOF
function cresamsu_${$}
;
compile_opt idl2, strictarrsubs
;
@cm_project
@common
;
result = -1
;
result_cresamsu = cresamsu('${numch}', ${yyyyb}, ${mmb}, ${ddb} $
        , ${yyyye}, ${mme}, ${dde} $
        , ${lonmin}, ${lonmax}, ${latmin}, ${latmax} $
        , '${temp}' , ${rtemp} , ${rhdeg})
result_type=size(result_cresamsu,/type)
result_type=size(result_cresamsu,/type)
IF (result_type EQ 3) THEN BEGIN
   IF (result_cresamsu NE 0) THEN BEGIN
       print, 'eee : pb cresamsu'
       return, result_cresamsu
   ENDIF
ENDIF
result = 0
;
return, result
end
EOF
unset numch
unset yyyyb
unset mmb
unset ddb
unset yyyye
unset mme
unset dde
unset lonmin 
unset lonmax 
unset latmin 
unset latmax
unset temp
unset rtemp
unset rhdeg 
#
${IDL_CMD} << EOF >> ${log} 2>&1
key_performance = 0
; totally shut down all profiling
profiler, /CLEAR, /SYSTEM & profiler, /CLEAR, /RESET
; add system procedure
Profiler, /SYSTEM
; compile users procedures to be scan by Profiler
.compile cresamsu
.compile idl_amsu_netcdf 
.compile geolocation_to_string_idl
.compile file_amsu_t2_to_mem
; add users procedures
Profiler
result = cresamsu_${$}()
print, 'result : ', result
print, 'ppp : profiler report begin'
Profiler, /REPORT
print, 'ppp : profiler report end'
EOF
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee: ${IDL_CMD} failed : ${status}" >> ${log} 2>&1
   cat ${PROJECT}/src/cresamsu_${$}.pro >> ${log} 2>&1
   exit 1
fi
rm ${PROJECT}/src/cresamsu_${$}.pro
unset status
# get current time at the end of the process
timeed="$(date +%s)"
elapsed_seconds="$(( ${timeed} - ${timebd} ))"
echo "${command} : iii : Elapsed time (s) : ${elapsed_seconds}" >> ${log} 2>&1
unset timebd
unset timeed
unset elapsed_seconds
#
unset yyyymmddb_min
unset yyyymmdde_max
unset force
unset debug
#
unset command
unset log
unset hostname
unset usage
#
unset date_cmd
#
# end
#set
exit
