function [west_zi, east_zi, north_zi, south_zi] = get_zi_geolocation(zi, west_value, east_value, north_value, south_value, zi_code)

%GET_STATION_GEOLOCATION returns geolocation of a given zone of interest

%
%+
%
% ====================
% get_zi_geolocation.m
% ====================
%
% .. function:: get_zi_geolocation(zi)
%
% DESCRIPTION
% ===========
%
%    :param zi: zi we are looking for
%    :type zi: string
%    :raise zi: required
%
%    :param west_value: west most longitudes
%    :type west_value: 1d array of doubles
%
%    :param east_value: east most longitudes
%    :type east_value: 1d array of doubles
%
%    :param north_value: north most latitudes
%    :type north_value: 1d array of doubles
%
%    :param south_value: south most latitudes
%    :type south_value: 1d array of doubles
%
%    :param zi_code: codes of the zone of interest
%    :type zi_code: 1D cell array of strings
%    :raise zi_code: required
%
% Look for ``zi`` in ``zi_code`` array and return associated information.
%
% If no match found or multiple matches found, returned values are set to NaN.
%
% EXAMPLES
% ========
%
% see demos
%
% SEE ALSO
% ========
%
% :ref:`zones`
%
% :func:`simul_zi`
% :func:`read_zi`
%
% TODO
% ====
%
% check arguments (type, size, value)
%
% status de retour
%
% description du rsultat en ReST
%
% exact match : now asking for "ferl" is ok but it should be so !!
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/get_zi_geolocation.m $
%
% - fplod 20110629T104405Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
%
% init of results
west_zi=NaN;
east_zi=NaN;
north_zi=NaN;
south_zi=NaN;
%
usage='[west_zi, east_zi, north_zi, south_zi] = get_zi_geolocation(zi, west_value, east_value, north_value, south_value, zi_code)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('zi');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg zi' arg_info.class]);
   whos zi
   error(usage);
end
clear arg_info
%
% +todo+   disp('arg zi must be a cell array of strings');
%
arg_info=whos('west_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg west_value' arg_info.class]);
   whos west_value
   error(usage);
end
clear arg_info
%
if ~isvector(west_value)
   disp('arg west_value must be a vector');
   error(usage);
end
%
arg_info=whos('east_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg east_value ' arg_info.class]);
   whos east_value
   error(usage);
end
clear arg_info
%
if ~isvector(east_value)
   disp('arg east_value must be a vector');
   error(usage);
end
%
arg_info=whos('north_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg north_value' arg_info.class]);
   whos north_value
   error(usage);
end
clear arg_info
%
if ~isvector(north_value)
   disp('arg north_value must be a vector');
   error(usage);
end
%
arg_info=whos('south_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg south_value ' arg_info.class]);
   whos south_value
   error(usage);
end
clear arg_info
%
if ~isvector(south_value)
   disp('arg south_value must be a vector');
   error(usage);
end
%
clear arg_info
%
arg_info=whos('zi_code');
if ~strcmp(arg_info.class,'cell')
   disp(['Incorrect type of arg zi_code ' arg_info.class]);
   whos zi_code
   error(usage);
end
clear arg_info
%
% +todo+   disp('arg zi_code must be a cell array of strings');
%
nb_zi=size(zi_code,1);
%
% look for identical string in zi_code array
result_match=strncmp(zi, zi_code, size(zi,2));
result_match=transpose(result_match);
%
% test if match found
if (~any(result_match))
   error(['eee : ' mfilename ' : ' 'no match found for zi ' zi]);
end
%
% test if multiple match
if (size(find(result_match),2) > 1)
   disp([' eee : ' mfilename ' : ' 'list of match indices ' num2str(find(result_match))]);
   for imatch=1:size(find(result_match),2)
       array_match=find(result_match);
       disp([' eee : ' mfilename ' : ' 'match zi_code #' , num2str(array_match(imatch))]);
       disp([zi_code(array_match(imatch))]);
   end
   error(['eee : ' mfilename ' : ' 'multiple matches for zi ' zi]);
end
if (size(find(result_match)) == 1)
   north_zi=north_value(result_match);
   south_zi=south_value(result_match);
   west_zi=west_value(result_match);
   east_zi=east_value(result_match);
end
%
%whos
%
end

%!demo
%! % To find `ferlo` geolocation::
%! close all
%! clear all
%! varamma_startup
%! more off
%! [west_value, east_value, north_value, south_value, zi_code, zi_description] = read_zi();
%! zi = 'ferlo';
%! [west_zi, east_zi, north_zi, south_zi] = get_zi_geolocation(zi, west_value, east_value, north_value, south_value, zi_code)
%
