function [result] = histo_intensityMSG(ij_intensity, Annee, Mois, Jour, nbclasses)

%HISTO_INTENSITYMSG trace la distribution des intensits de l'activiti
%nuageuse, sur une journe, estime d'aprs MSG

%
%+
%
% ====================
% histo_intensityMSG.m
% ====================
%
% .. function:: histo_intensityMSG(ij_intensity, Annee, Mois, Jour, nbclasses)
%
% DESCRIPTION
% ===========
%
% - Donnes d'entres :
%
%   * Annee (en caractres) : Anne (AAAA) du jour d'tude.
%   * Mois (en caractres) : Numro du mois (MM) du jour d'tude.
%   * Jour (en caractres) : Numro du Jour d'tude (JJ).
%   * ij_intensity : Donnes d'intensits estimes sur une journe dans
%     notre domaine d'tude.
%   * nbclasses : Nombres de classes dans l'histogramme.
%
% Traage de la distribution des intensits de l'activiti nuageuse, sur
% une journe, estime d'aprs MSG, dans notre domaine d'tude
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :func:`MSGread`
%
% :func:`intensityMSG_day`
%
% TODO
% ====
%
%
% - fplod 20110609T072543Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * pb cratos octave::
%
%        A(I,J): column index out of bounds; value 1 out of bound 1
%
% very strange figure produce by demo : check handling of "0" data
%
% save figure
%
% demo with :func:`simul_msg`
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/histo_intensityMSG.m $
%
%
% - fplod 20110830T074359Z cratos (Linux)
%
%   * suppress interactivity
%
% - pinsard 2011-05-26T07:52:18Z loholt1.ipsl.polytechnique.fr
%
%   * suppress full screen
%
% - fplod 20110309T170001Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * suppress fontsize and fontname (known problem for octave)
%
% - fplod 20110304T085500Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 20110303
%
%   * Ajout de la doc et de la dmonstration
%
% - jaclod 20110226
%
%   * Cration
%
%-
%
result=-1;
%
usage='[result] = histo_intensityMSG(ij_intensity, Annee, Mois, Jour, nbclasses)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%%%%%%%%%%%%%
% Paramtres
%%%%%%%%%%%%%


% Ouverture/Modification d'une figure 
figure()

% On place les valeurs sur un seul vecteur.
DistribIntensity = reshape(ij_intensity,1,[]);

% On dfinit les diffrentes valeurs centrales de l'histogramme. On le
% dcoupe en un nombre de classes prcdemment dfinit.
X = min(DistribIntensity):(max(DistribIntensity)-min(DistribIntensity))/(nbclasses-1):max(DistribIntensity);

% On trace l'histogramme.
hist(DistribIntensity,X);

% Ajout de titres.
xlabel('Intensit (unit arbitraire)');
ylabel('Nombre de points')
title(['Distribution des intensits pour le ' ([Annee '-' Mois '-' Jour])])

result=0;

end

%!demo
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! latmin = 10;
%! latmax = 20;
%! lonmin = -20;
%! lonmax = -10;
%! nbclasses = 15;
%! [TbMSG, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = MSGread(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax);
%! [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau, TbMSG] = intensityMSG_day(Temps, TbMSG);
%! result = histo_intensityMSG(ij_intensity, Annee, Mois, Jour, nbclasses);
