; docformat = 'rst'
;+
; .. _read_amsua1c.pro:
;
; ================
; read_amsua1c.pro
; ================
;
; Reads AMSU-B Level 1C Data from AAPP-formatted input
; Ralf Bennartz 2 August 1999
;
; :Uses:
;
; :Restrictions:
;
; :Pre:
;
; :Post:
;
; :Todo:
;
; examples
;
; :Examples:
;
; To read an AMSU NOAA15 file::
;
;    filename="/homedata/pinsard/varamma_d/AMSU/AMSUAN15/L1C/2006/2006_08_01/NSS.AMAX.NK.D06213.S0110.E0255.B4271112.GC.L1C"
;    flag1=-9
;    COMMON amsua_header,ama_head
;    COMMON amsua_data  ,ama_scan
;    read_amsua1c, filename, flag1
;    print, flag1
;    print,'NUMERO DU SATELLITE ',ama_head.h_satid
;    print,'INSTRUMENT',ama_head.h_instrument
;
; To read an METOP file::
;
;    filename="/homedata/pinsard/varamma_d/AMSU/AMSUAM02/L1C/2007/2007_08_01/NSS.AMAX.M2.D07213.S0115.E0259.B0405455.SV.L1C"
;    flag1=9
;    COMMON amsua_header,ama_head
;    COMMON amsua_data  ,ama_scan
;    read_amsua1c, filename, flag1
;    print, flag1
;    print,'NUMERO DU SATELLITE ',ama_head.h_satid
;    print,'INSTRUMENT',ama_head.h_instrument
;
; :History:
;
;  $Id: read_amsua1c.pro 235 2011-05-16 15:52:50Z pinsard $
;
; - pinsard 20120530T144236Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * add some examples
;
; - fplod 20120420
;
;   * use get_lun instead of hard coded unit
;
; - fplod 20120417
; 
;   * usage of key_performance
;
; - pinsard 2011-05-16T13:14:37Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * compile_opt
;
; - fplod 20100701T130054Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
PRO read_amsua1c,filename, flag1
;
compile_opt idl2, strictarrsubs
;
@common
s = size(SCOPE_TRACEBACK(/STRUCTURE),/DIMENSION)
routine = (SCOPE_TRACEBACK(/STRUCTURE))[s-1].Routine
;
if key_performance EQ 1 THEN BEGIN
    time1 = SYSTIME(1)
ENDIF
;
COMMON amsua_header,ama_head
COMMON amsua_data  ,ama_scan
;
; Open input file
OPENR, lu,filename, ERROR = error,/GET_LUN
IF (error NE 0) then begin
   ras = report(['eee : can not open for reading'$
         + '!C' $
         + 'code : ' + !ERROR_STATE.MSG $
         + filename])
   STOP
ENDIF
;
; Define and read in header structure
define_amsua_header_struct
READU, lu, ama_head
; byteorder,ama_head,/Lswap
;
; Define and read in data structure
define_amsua_struct,one_scana, flag1
if (flag1 eq 0) then goto, pb_file
;READU,1,ama1cdt
; read each scanline sperately
FOR i = 0L,ama_head.h_scnlin-1 DO BEGIN
   ; if (eof(lu) eq 0) then goto, pb_file
   READU, lu, one_scana
   ;byteorder,one_scana,/Lswap
   ama_scan[i] = one_scana
ENDFOR
;
; Close input file
pb_file:
CLOSE, lu
FREE_LUN, lu

IF key_performance EQ 1 THEN BEGIN
   msg = report(['ppp : ' + routine + ' : dure totale ' $
               + string(SYSTIME(1)-time1,format='(F12.6)')])
ENDIF

END
