function [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value]=read_lai_gis(yyyy, nbligne, zi_code)

%READ_LAI_GIS fill LAI 2D array and associated arrays date, lat, lon, vegetation classe, pedology classe, etc.
% with data in :file:`${PROJECT_ID}/LAI/LAI{yyyy}F_veg2010_sol.csv`
% or in :file:`${PROJECT_ID}/LAI/LAI{yyyy}F_veg2010_sol_{zi_code}.csv`

%
%+
%
% ==============
% read_lai_gis.m
% ==============
%
% .. function:: read_lai_gis(yyyy, nbligne, zi_code)
%
% DESCRIPTION
% ===========
%
%    :param yyyy: year
%    :type yyyy: uint16
%    :raise yyyy: required ex 2008
%
%    :param nbligne: nb ligne a lire ex 10000
%    :type nbligne: uint16
%    :raise nbligne: required
%
%    :param zi_code: zi_code ex 'barkedji'
%    :type zi_code: string
%
% read file :file:`${PROJECT_ID}/LAI_CSV/LAI{yyyy}F_veg2010_sol.csv`
% if **zi_code** is ``ferlo``.
% or :file:`${PROJECT_ID}/LAI_CSV/LAI{yyyy}F_veg2010_sol_{zi_code}.csv`
% if **zi_code** is not ``ferlo``.
%
% if **nbligne** is set to *0*, all lines are read, else only **nbligne** are read.
%
% return associated arrays lat, lon, lai, vegetation class , pedology class
%
% Les dates au format `yyyymmddhhmn` sont stockes dans le tableau
% **datestr_value** et les dates en jour julien sont stockes dans
% **datejul_value**.
%
% corrige pb de colonne mapusub souvent vide de donnees avec
% textedit (remplace ;; par ;" ";)
%
% lecture reussie sur un nb limite de lignes, mais pb memoire pour
% traitement du fichier complet (sur mon Mac)
%
% corrige quelques pbs dans le prgm (inversion colonnes, ismember
% remplace par isnan,...)
%
% pb de memoire: impossible d'avoir l'allocation memoire pour les 50000 lignes
% du fichier
% fonctionne jusqu'a 45000 lignes (sur cratos).
%
% EXAMPLES
% ========
%
% see demo
%
% TIPS
% ====
%
% To see the first line (header) of this kind of file::
%
%   $  sed -ne "1,1p" LAI2008F_veg2010_sol.csv
%
% To see the second line (first line of data) of this kind of file::
%
%   $  sed -ne "2,2p" LAI2008F_veg2010_sol.csv
%
% SEE ALSO
% ========
%
% :ref:`data_lai`
% :ref:`zones`
%
% :func:`simul_lai_gis` ++
% :func:`write_lai_gis`
% :func:`plot_lai_gis`
% :func:`select_lai_gis`
% :func:`graphe_zicode`
%
% :func:`read_lai_2d.m`
%
% TODO
% ====
%
% handling error if nbligne > nb of data lines in the file
%
% il ne devrait plus y avoir des lignes avec tous le LAI  NaN ici
% elles devraient tre filtres par le SIG.
%
% how to check if outputs are correct in demo 1 (real file)
%
% add simulation demo
%
% coding rules
%
% check zi_code with get_zi_geolocation
%
% pb si yyyy int16 sur skylla (mac lelod)
%
% KNOWN ISSUES
% ============
%
% heterogeneity between files in labels names
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/read_lai_gis.m $
%
%
% - fplod 20110920T091450Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace num2str(yyyy) by int2str(yyyy) because octave error
%     on cratos
%
% - fplod 20110915T155109Z cratos (Linux)
%
%   * add labels name to support heterogeneity between files
%   * can not anymore check for too many item
%   * suppress gridcode_value from output
%   * suppress unused fields (mnage ...)
%
% - fplod 20110915T085736Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * rase on error if unexpected label
%
% - fplod 20110909T151503Z cratos (Linux)
%
%   * change rule about emptyness of zi_code : must be either ``ferlo``
%     or an other known zi_code
%
% - fplod 20110818T143913Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * if nbligne is set to 0, read all lignes
%   * counting lines from http://groups.google.com/group/comp.soft-sys.matlab/browse_thread/thread/8c20ddd634b94f50?pli=1
%   * add 2 demos to read all lines
%
% - fplod 20110816T072422Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace int16 by uint16 for integer parameters
%   * pb matlab 7.4 sur cratos plante sur
%     :samp:`classes_value=repmat({'NaN'},nb_line_data_max,1);`
%     si nb_line_data_max est un int16. solution
%     utilisation de la commande double.
%
% - soclod/fplod 20110812T145018Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * run demo with LAI2008F_veg2010_sol_barkedji.csv
%
% - fplod 20110812T125939Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace la2008i_Clip_Intersect_Inter.csv by LAI2008F_veg2010_sol.csv
%   * restore argument checking
%   * restore detection of lines with too many items
%   * replace nbpluvio parameter with zi_code
%   * update first demo (missing nbligne parameter, too many outputs)
%
% - lelod 20110810
%
%   * ajout revoir option zone pluvio dans l'appel et dans la lecture
%     (fait a la barbare)
%
% - lelod 20110728
%
%   * pour developpements d'analyse LAI par Soukeye, ajout du parametre
%     nbligne dans la fonction
%
% - fplod 20110708T085037Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * reading data line using technique of read_zi.m
%     because of string values dmlread connaot be used
%   * file written in correct format (. for decimal, ";" as
%     separator, float values for numbers (no more string for
%     numeric values)   - lelod 20110720
%   * add datejul_value output and all GIS info
%
% - fplod 20110706T154713Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation draft from la2008i_Clip_Intersect_Inter.csv produce by
%     openoffice saving la2008i_Clip_Intersect_Inter.dbf in CSV format
%     and read_lai_2d.m
%
%     cautions : some modification on the original test file
%     because too many user's no friendly features.
%-
%
global PROJECT_ID
%
usage='[lon_value, lat_value, datejul_value, datestr_value,lai_value, classes_value, msdnom_value]=read_lai_gis(yyyy, nbligne, zi_code)';
%
if nargin~=nargin(mfilename)
    disp(['Incorrect number of input arguments ' num2str(nargin)]);
    error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('yyyy');
if ~strcmp(arg_info.class,'uint16')
    disp(['Incorrect type of arg yyyy ' arg_info.class]);
    error(usage);
end
clear arg_info
%
arg_info=whos('nbligne');
if ~strcmp(arg_info.class,'uint16')
    disp(['Incorrect type of arg nbligne ' arg_info.class]);
    whos nbligne
    error(usage);
end
clear arg_info
%
arg_info=whos('zi_code');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg zi_code' arg_info.class]);
   whos zi_code
   error(usage);
end
clear arg_info
%
% build filename to be read
switch zi_code
    case {'ferlo'}
       fullfilename=[ PROJECT_ID 'LAI_CSV/LAI' int2str(yyyy) 'F_veg2010_sol.csv'];
    otherwise
       fullfilename=[ PROJECT_ID 'LAI_CSV/LAI' int2str(yyyy) 'F_veg2010_sol_' zi_code '.csv'];
end
disp(['iii : opening for reading ', fullfilename]);
% opening file
[fid,message]=fopen(fullfilename,'r');
% test if fullfilename exists
if (fid == -1)
    disp(message)
    error([ fullfilename ' not exist'])
end
clear message
%
% first line contains "lat","lon" and
% an unknown quantity of days of years
% so we read this line and loop to find the number of columns
%
% get first line as a string
header_line = fgetl(fid);
%
% loop to find the number of columns
% and initialize the "day of year" array
index_column = 0;
% the maximum of doy is the number of days in year yyyy
% divided by 8 (according to time resolution of this dataset)
yyyy_d=double(yyyy);
nb_doy_max=ceil((datenum(yyyy_d,12,eomday(yyyy_d,12)) - datenum(yyyy_d,1,1))/8);
% attention les semaines sont de 7 jours )--> 52 semaines (avec 8j,
% on tombe a 46)
doy=zeros(nb_doy_max,1);
doy(:)=NaN;
nb_gis_label = 0;
while ( ~isempty(header_line) )
  % parse next column label
  [next,header_line] = strtok(header_line,';');
  switch next
     case {'"Y"'}
     case {'"X"'}
     case {'"FID_occups"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"FID_occu_1"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"ID"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"GRIDCODE"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"FID_bvferl"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"FID_bvfer"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"ID_1"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"GRIDCODE_1"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"classes"'}
         nb_gis_label = nb_gis_label + 1;
	 index_classes = nb_gis_label;
     case {'"FID_ferlos"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"AREA"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"PERIMETER"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"SGSOLRU_"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"SGSOLRU"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"SGSOLRU_ID"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"MAPU"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"MAPUSUB"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"MSD"'}
         nb_gis_label = nb_gis_label + 1;
     case {'"MSDNOM"'}
         nb_gis_label = nb_gis_label + 1;
	 index_msdnom = nb_gis_label;
     case {'"Id_12"'}
         nb_gis_label = nb_gis_label + 1;
     otherwise
        % here we expect somesthing like "doy"
        % for example day 9 will be coded "9"
        % ++ todo regexp
        [sdoy, extra_sdoy] = strtok(next,';');
        clear extra_sdoy
        doy_string = sdoy;
        %(1,3:end); plus utile, puisque header nettoye a la fabrication
        clear sdoy
        if ~isnan(str2double(doy_string))
           doy(index_column - 1) = str2double(doy_string);
        else
           error(['eee : unexpected label name %s ' doy_string]);
        end
        clear doy_string
  end
  clear next
  % increase index of column
  index_column = index_column + 1;
end
%
nb_doy = index_column - 2 - nb_gis_label;
clear index_column
%
index_classes = index_classes + nb_doy + 2;
index_msdnom = index_msdnom + nb_doy + 2;
%
% remove extra doy NaN values due to preallocation
doy=doy(~isnan(doy));
%
% initialisation d'un tableau string de nb_doy elements  9999999
datestr_value=repmat('99999999',nb_doy,1);
for index_doy=1:nb_doy
    datejul_value(index_doy)=datenum(yyyy_d,1,1) + doy(index_doy) - 1;
end
datestr_value=datestr(datejul_value,'yyyymmdd');
%
% preallocation of output arrays to missing value: attention:
% entre en parametre
if (nbligne > 0)
    nb_line_data_max = nbligne;
else
    % scan the file to count lines
    fh = fopen(fullfilename, 'r');
    chunksize = 1e6;
    nbligne = 0;
    while ~feof(fh)
         ch = fread(fh, chunksize, 'uchar');
         if isempty(ch)
             break
         end
         nbligne = nbligne + sum(ch == char(10));
    end
    fclose(fh);
    nb_line_data_max = nbligne;
end
% ++ fichier (50247 lignes?)
%
lat_value=zeros(1,nb_line_data_max);
lat_value(:)=NaN;
lon_value=zeros(1,nb_line_data_max);
lon_value(:)=NaN;
lai_value=zeros(nb_doy,nb_line_data_max);
lai_value(:,:)=NaN;
classes_value=repmat({'NaN'},double(nb_line_data_max),1);
msdnom_value=repmat({'NaN'},double(nb_line_data_max),1);
%
% reading data from file (from second line)
index_line_data=1;
%
while (index_line_data < nb_line_data_max)
%
  data_line = fgetl(fid);
  % loop to handle each item on the data line (";" separated value)
  % attention, il arrive qu'une cellule soit vide (mapusub) : corrige en principe
  index_item=1;
  while (~isempty(data_line))
     % parse next column label
     [item,data_line] = strtok(data_line,';');
     if (index_item == 1 )
       lat_value(index_line_data)=str2double(item);
     elseif (index_item == 2 )
       lon_value(index_line_data)=str2double(item);
     elseif (index_item > 2 && index_item <= 2 + nb_doy)
       lai_value(index_item - 2, index_line_data)=str2double(item);
     elseif (index_item == index_classes)
       classes_value(index_line_data)=cellstr(item);
     elseif (index_item ==  index_msdnom)
       msdnom_value(index_line_data)=cellstr(item);
     end
     clear item
     % increase index of item
     index_item = index_item + 1;
  end
  index_line_data=index_line_data+1;
  clear data_line
  clear index_item
end
if (index_line_data > nb_line_data_max+1)
  error([' need to increase nb_line_data_max up to ' num2str(index_line_data) ]);
end
%
clear index_line_data
%
fclose(fid);
clear fid
%
% remove extra data NaN values due to preallocation
% criteria = when lon_value is not NaN
missing_data_indices=find(isnan(lon_value));
if (~isempty(missing_data_indices))
    nb_data=min(missing_data_indices)-1;
    lat_value=lat_value(1:nb_data);
    lon_value=lon_value(1:nb_data);
    lai_value=lai_value(:,1:nb_data);
    classes_value=classes_value(1:nb_data);
    msdnom_value=msdnom_value(1:nb_data);
end
%
clear nb_line_data_max
%
%whos
%
result=0;
end

%!demo
%! % To read the first 1000 lines of
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy=uint16(2008);
%! nbligne=uint16(10);
%! zi_code='ferlo';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value]=read_lai_gis(yyyy, nbligne, zi_code);
%! datestr_value
%! msdnom_value
%! classes_value
%! whos lai_value

%!demo
%! % To read all lines of
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy=uint16(2008);
%! nbligne=uint16(0);
%! zi_code='ferlo';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value]=read_lai_gis(yyyy, nbligne, zi_code);
%! datestr_value
%! msdnom_value
%! classes_value
%! whos lai_value

%!demo
%! % To read the first 10 lines of
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(10);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! datestr_value
%! msdnom_value
%! classes_value
%! whos lai_value

%!demo
%! % To read all lines of
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(0);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! datestr_value
%! msdnom_value
%! classes_value
%! whos lai_value
