function [datejul_valueout, datestr_valueout, lai_valueout]=select_lai_gis(datejul_value, datestr_value, lai_value, yyyymmddb, yyyymmdde)

%SELECT_LAI_GIS selection des lai en fonction du temps

%+
%
% ================
% select_lai_gis.m
% ================
%
% .. function:: select_lai_gis(datejul_value, datestr_value, lai_value, yyyymmddb, yyyymmdde)
%
% DESCRIPTION
% ===========
%
%   :param datejul_value: Julian dates of data
%   :type datejul_value: 1D of floats
%   :raise datejul_value: required
%
%   :param datestr_value: dates yyyymmdd of data
%   :type datestr_value: 1D of strings
%   :raise datestr_value: required
%
%   :param lai_value: LAI values (data)
%   :type lai_value: 2D of floats, dim 1 index of time, dim 2 index of (lat,lon) point
%   :raise lai_value: required
%
%   :param yyyymmddb: beginning date yyyymmdd
%   :type yyyymmddb: double
%   :raise  yyyymmddb: required
%
%   :param yyyymmdde: end date yyyymmdd
%   :type yyyymmdde: double
%   :raise yyyymmdde: required
%
% selection des lai entre date dbut et date fin
%
% EXAMPLES
% ========
%
% see demo
%
% SEE ALSO
% ========
%
% :ref:`data_lai`
%
% :ref:`varamma_startup.m`
%
% Use : :func:`split_yyyymmdd`
%
% May be used after :func:`read_lai_gis` and before :func:`plot_lai_gis`
%
% TODO
% ====
%
% status de retour
%
% check argument
%
% missing value
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20111115T093329Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%-
%
usage='[datejul_valueout, datestr_valueout, lai_valueout]=select_lai_gis(datejul_value, datestr_value, lai_value, yyyymmddb, yyyymmdde)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('yyyymmddb');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg yyyymmddb ' arg_info.class]);
   whos yyyymmddb
   error(usage);
end
clear arg_info
%
arg_info=whos('yyyymmdde');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg yyyymmdde ' arg_info.class]);
   whos yyyymmddb
   error(usage);
end
clear arg_info
%
[yyyyb, mmb, ddb] = split_yyyymmdd(yyyymmddb);
[yyyye, mme, dde] = split_yyyymmdd(yyyymmdde);
datenum_begin = datenum(yyyyb,mmb,ddb);
clear yyyyb
clear mmb
clear ddb
datenum_end = datenum(yyyye,mme,dde);
clear yyyye
clear mme
clear dde
index_timevalid = find(datejul_value >= datenum_begin & datejul_value <= datenum_end);
clear datenum_begin
clear datenum_end
%
% test if index pas vide
if ~isempty(index_timevalid)
   datejul_valueout = datejul_value(index_timevalid);
   datestr_valueout = datestr_value(index_timevalid,:);
   lai_valueout = lai_value(index_timevalid,:);
else
   disp(['iii : no date found between ', num2str(yyyymmddb), ' and ', num2str(yyyymmdde)])
   datejul_valueout = [];
   datestr_valueout = [];
   lai_valueout = [];
end
clear index_timevalid

end

%!demo
%! % To read the first 1000 lines of
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol.csv
%! % and select data between 20080601 and 2001231
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy=uint16(2008);
%! nbligne=uint16(10);
%! zi_code='ferlo';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value]=read_lai_gis(yyyy, nbligne, zi_code);
%! yyyymmddb = 20080601;
%! yyyymmdde = 20081231;
%! [datejul_valueout, datestr_valueout, lai_valueout] = select_lai_gis(datejul_value, datestr_value, lai_value, yyyymmddb, yyyymmdde);
%! whos
