function [result] = stagejasonjuillet()

%STAGEJASONJUILLET permet d'utiliser les fonctions crees durant le stage de
%de Jason de juillet 2011 et d'en refaire les figures.

%
%+
%
% ===================
% stagejasonjuillet.m
% ===================
%
% .. function:: stagejasonjuillet()
%
% DESCRIPTION
% ===========
%
% permet d'utiliser les fonctions crees durant le stage de
% de Jason de juillet 2011 et d'en refaire les figures.
%
% EXAMPLES
% ========
%
% see "demos"
%
% SEE ALSO
% ========
%
% :func:`cumulEPSAT_concat`
% :func:`intensityMSG_concat`
% :func:`meanandstdplot`
% :func:`hovmullerlonorlat`
% :func:`histoplot`
% :func:`missingdaytonan`
% :func:`box5x5serietemp`
% :func:`int2precipu`
% :func:`nonprecipperiods`
%
% TODO
% ====
%
% severe crash matlab 2010 on cratos due to pb on nonprecipperiods.m
%
% avoid load/save
%
% path of load/save file
%
% ::
%    fplod@cratos$ ls -l /usr/home/jaclod/Documents/MATLAB/dataintandprecip2006.mat
%    ls: cannot access /usr/home/jaclod/Documents/MATLAB/dataintandprecip2006.mat: Permission denied
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110830T080318Z cratos (Linux)
%
%   * add missing output arguments
%
% - fplod 20110829T122111Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add demo
%   * usage of load and save function vs command
%   * explicit exetension on mat file (defaut octave is txt)
%   * replace ~ by variable to please matlab 7.4 on cratos
%
% - jaclod 2011-08-05
%
% * Ajout de la documentation et des commentaires.
%
% - jaclod 2011-08-01
%
%   * Creation.
%
%-
result = -1;
usage='result=stagejasonjuillet()';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
close all

%%%%%%%%%%
% Donnees
%%%%%%%%%%

% Chargement des donnees cotieres.
load('cmgco_traitdecote.mat','Xgco','Ygco');

% Chargement des donnees si elles ont ete enregistrees sinon on les
% recuperes (tres long, 1h environ la premiere fois et trop long pour
% attendre la fin une seconde fois, peut-etre trop de monde sur cratos a ce
% moment la...).
if exist('dataintandprecip2006.mat','file');
    load(dataintandprecip2006.mat');
else
    [ij_cumul_concat, time_cumul_concat, Longitudes, Latitudes] = cumulEPSAT_concat('extracted', 0,0,0,0,0,0,2006);
    [ij_intensity_concat, time_intensity_concat, Longitudes, Latitudes] = intensityMSG_concat('extracted', 0,0,0,0, 200, 200, 2006);
    % Ou pour les fichiers non extraits :
    % [ij_cumul_concat, time_cumul_concat, Longitudes, Latitudes] = cumulEPSAT_concat('normal', -20,0,0,20,0,0,2006);
    % [ij_intensity_concat, time_intensity_concat, Longitudes, Latitudes] = intensityMSG_concat('normal', -20,0,0,20, 200, 200, 2006);
    %++ save('dataintandprecip2006.mat');
end

%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Moyennes et ecart-types des intensites sur la saison 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[meandata, stddata] = meanandstdplot(ij_intensity_concat, time_intensity_concat, Longitudes, Latitudes, 'intensites');

% Ajout des cotes (N'est que present automatiquement dans
% 'nonprecipperiods', ajoute a la fin du stage).
hold on
plot(Xgco,Ygco,'k.');
subplot(1,2,1)
hold on
plot(Xgco,Ygco,'k.')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Moyennes et ecart-types des cumuls EPSAT sur la saison 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Attention il y a un jour ou il n'y a que des NaN (le 48e). On le supprime
% pour que la fonction 'meanandstdplot' marche, il faudrait automatiser
% cela directement dans la fonction. (cf. fonction 'nonprecipperiods' qui le
% fait avec le code qui suit).

% Extrait de 'nonprecipperiods' :
% Suppressions des donnees pour les jours ou nous avons que des 'NaN'.
% On cherche s'il y en a, quels sont les pas de temps concernes et leur
% nombre.
indnan = find(isnan(ij_cumul_concat(:,1,1)));
nbnan = size(indnan,1);

% S'il y en a, on va les supprimer.
if ~isempty(indnan);

    % On boucle pour supprimer chaque pas de temps concernes en commencant
    % par les derniers (si on souhaite par exemple supprimer les pas de
    % temps 2 et 5 et que l'on supprime le 2 d'abord, le 5e pas de temps
    % sera ensuite decale au 4e. En commencant par la fin, cela ne se
    % produit pas).
    for nansuppr = 1 : nbnan;

        ij_cumul_concat(indnan(nbnan - nansuppr + 1),:,:) = [];

        time_cumul_concat(indnan(nbnan - nansuppr + 1)) = [];

    end

end

clear('indnan','nbnan','nansuppr');

[meandata, stddata] = meanandstdplot(ij_cumul_concat, time_cumul_concat, Longitudes, Latitudes, 'cumuls EPSAT (mm)');

hold on
plot(Xgco,Ygco,'k.');
subplot(1,2,1)
hold on
plot(Xgco,Ygco,'k.')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Diagramme de hovmuller des intensites et cumuls EPSAT sur 15 jours
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Diagrammes realises sur les 15 jours en communs avant rapatriement de
% l'ensemble de la saison c'est--dire du 26 juillet au 09 aout 2006.

% Diagrammes de hovmullet latitudes vs temps pour des donnees moyennes sur
% 0.5 degres autour de -4 en longitudes.
[hovdata] = hovmullerlonorlat(ij_intensity_concat(26:40,:,:),time_intensity_concat(26:40),Longitudes,Latitudes,2,-4,0.5,'intensites');
[hovdata] = hovmullerlonorlat(ij_cumul_concat(26:40,:,:),time_cumul_concat(26:40),Longitudes,Latitudes,2,-4,0.5,'cumuls EPSAT');

% Autour de -14 cette fois.
[hovdata] = hovmullerlonorlat(ij_intensity_concat(26:40,:,:),time_intensity_concat(26:40),Longitudes,Latitudes,2,-14,0.5,'intensites');
[hovdata] = hovmullerlonorlat(ij_cumul_concat(26:40,:,:),time_cumul_concat(26:40),Longitudes,Latitudes,2,-14,0.5,'cumuls EPSAT');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Distributions des intensites et cumuls EPSAT sur la saison 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure
status_histo=histoplot(ij_cumul_concat,14,'cumuls EPSAT (mm)','sur la saison 2006');
figure
status_hisot=histoplot(ij_intensity_concat,14,'intensites','sur la saison 2006');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Comparaison des series temporelles sur la saison dans 5x5 degres
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[ij_intensity_concat_withnan, time_intensity_concat_complete] = missingdaytonan(ij_intensity_concat, time_intensity_concat);
[ij_cumul_concat_withnan, time_cumul_concat_complete] = missingdaytonan(ij_cumul_concat, time_cumul_concat);

ij_intensity_concat_withnan = 0.022685*ij_intensity_concat_withnan + 0.8366;

status_box5x5serietemp = box5x5serietemp(ij_intensity_concat_withnan, time_intensity_concat_complete);
status_box5x5serietemp = box5x5serietemp(ij_cumul_concat_withnan, time_cumul_concat_complete);

clear('ij_intensity_concat_withnan', 'time_intensity_concat_complete', 'ij_cumul_concat_withnan', 'time_cumul_concat_complete');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Validation croisee sur plusieurs zones
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

lonmin = [-20 -10 -20 -20];
lonmax = [-10 0 0 0];
latmin = [10 10 5 0];
latmax = [20 20 10 5];

for zone = 1:4;
    status = MSGanalysiscrossvalidation(ij_intensity_concat, ij_cumul_concat, time_intensity_concat, time_cumul_concat, Longitudes, Latitudes, lonmin(zone), lonmax(zone), latmin(zone), latmax(zone));
end

clear('lonmin','lonmax','latmin','latmax','zone');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Passage des intensites en precipitations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[ij_intensity_concat_precip] = int2precip(ij_intensity_concat, 'global', Longitudes, Latitudes);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Comparaison des nouvelles cartes sur la saison
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[meandata, stddata] = meanandstdplot(ij_intensity_concat_precip, time_intensity_concat, Longitudes, Latitudes, 'cumuls (mm) par analyse des intensites');

hold on
plot(Xgco,Ygco,'k.');
subplot(1,2,1)
hold on
plot(Xgco,Ygco,'k.')

clear ij_intensity_concat_precip;

[meandata, stddata] = meanandstdplot(ij_cumul_concat, time_cumul_concat, Longitudes, Latitudes, 'cumuls EPSAT (mm)');

hold on
plot(Xgco,Ygco,'k.');
subplot(1,2,1)
hold on
plot(Xgco,Ygco,'k.')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Suivi des pauses de precipitations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[meantimestepof0, stdtimestepof0] = nonprecipperiods(ij_intensity_concat, time_intensity_concat, Longitudes, Latitudes, 'intensites',  'avec restriction de l''echelle entre 0 et 5 jours', 0, 5, 0, 5);

[meantimestepof0, stdtimestepof0] = nonprecipperiods(ij_cumul_concat, time_cumul_concat, Longitudes, Latitudes, 'cumuls EPSAT',  'avec restriction de l''echelle entre 0 et 5 jours', 0, 5, 0, 5);

result = 0;

end

%!demo
%! varamma_startup;
%! more off
%! status = stagejasonjuillet()
