; docformat = 'rst'
;+
;
; .. _hovmuller.pro:
;
; =============
; hovmuller.pro
; =============
;
; plot hovmuller
;
; :Categories:
;  PNG
;  hoevmuller
;  AMSU
;  OLR
;
; :Params:
;  dataset : in, required, type='string'
;   dataset to plot
;  canal : in, optional, type='string'
;   canal of AMSU
;
;   only used if AMSU dataset
;
; :Keywords:
;  TIMEBOX : type='1D array of 2 long integers'
;   minimal and maximal date (YYYYMMDD) of data
;   YYYY should be 0000 when climatology data are used (see DATASETTYPE)
;
;  DATASETTYPE : default='for AMSU ++, for OLR ++'
;   dataset type name.
;   For each dataset, there are several file type (year vs total, global vs
;   regional). ++
;
;  AXE : default='latitude'
;   geographical axe to be use for hovmuller
;   can be either 'latitude' or 'longitude'
;
;  UBOX : type='1D array of 4 items'
;   latitudes and longitudes of the box in this order : ulon1 ulon2 ulat1 ulat2
;
;  OVERWRITE : default=false
;   to overwrite the output image file if exists.
;
;   Useless if NOSAVE is set.
;
;  NOSAVE : default=false
;   to NOT save the output image in a file
;
;   might be usefull if several plots are needed on the same figure.
;
;   file if exist might be overwritten if OVERWRITE is set to 1.
;
;  _EXTRA :
;   Used to declare that this routine accepts inherited keywords
;
;   see example with SMALL keyword
;
; :Restrictions:
;  - Requires SAXO
;
; :Returns:
;
; :Uses:
;  :ref:`pltt <saxo:pltt>`
;  :ref:`cm_4cal <saxo:cm_4cal>`
;
;  :ref:`forout.pro`
;
; :Pre:
;  :ref:`varamma_profile.sh`
;
;  for AMSU dataset be sure to have :file:`{c}{x}.an{yyyy}.nc`
;  in the directory defined in :file:`${PROJECT_ID}/`
;
;  for OLR dataset be sure to have :file:`olr.day.mean_{yyyy}_ng.nc`
;  in the directory defined in :file:`${PROJECT_ID}/`
;
; :Post:
;  :ref:`varamma_profile.sh`
;
; :Todo:
;
;  use geolocation_to_string_idl
;
;  find from where come this error
;  ::
;
;    % Type conversion error: Unable to convert given STRING to Long.
;
;
;  ++ check timebox (datemin, datemax) validity
;
;  ++ deal with multiple years (in input filenames) or wok with multiple years file (olr.day.mean.nc)
;
;  ++ exploitation du champ info des fichiers OLR
;
;  ++ gros souci avec les longitude OLR !!!! glam=[-180,180]
;
;  ++ split read and plot
;
;  ++ saveimage or openps (for image to provide to publisher)
;
;  ++ filename si small idiot car peut contenir plusieurs figures donc pas canal+year...
;
; :Examples:
;
;
; To plot AMSU a4 hovmuller latitude plot according to :file:`${PROJECT_ID}/a4.an2006.nc` between 2006040101 and 20061031 and produce a PNG file::
;
;    hovmuller, 'AMSU', 'a4', timebox=[20060401L,20061031L], AXE='latitude', ubox=[-30.,+40.,-30.,45.]
;
; To plot AMSU a4 and a5 hovmuller latitude plots according to :file:`${PROJECT_ID}/a[45].an2006.nc` between 2006040101 and 20061031 on the same figure::
;
;    hovmuller, 'AMSU', 'a4', timebox=[20060401L,20061031L], AXE='latitude', ubox=[-30.,+40.,-30.,45.], /nosave, small=[2,1,1]
;    hovmuller, 'AMSU', 'a5', timebox=[20060401L,20061031L], AXE='latitude', ubox=[-30.,+40.,-30.,45.], /noerase, /nocolorbar,small=[2,1,2]
;
; ++ les deux dessins n'occupent pas la mme taille.
;
; To plot OLR hovmuller latitude plot according to :file:`${PROJECT_ID}/olr.day.mean_2006_ng.nc` between 2006040101 and 20061031 and produce a PNG file name::
;
;    hovmuller, 'OLR', 'n.a.', timebox=[20060401L,20061031L], AXE='latitude', ubox=[-30.,+40.,-30.,45.]
;
; To plot OLR hovmuller longitude plot according to :file:`${PROJECT_ID}/olr.day.mean_2006_ng.nc` between 2006040101 and 20061031 and produce a PNG file::
;
;    hovmuller, 'OLR', 'n.a', timebox=[20060401L,20061031L], AXE='longitude', ubox=[-30.,+40.,-30.,45.]
;
; To plot AMSU a4 hovmuller latitude plot climatology and produce a PNG file::
;
;    hovmuller, 'AMSU', 'a4', timebox=[00000401L,00001031L], DATASETTYPE='varamma_t3', AXE='latitude', ubox=[-30.,+40.,-30.,45.]
;    hovmuller, 'AMSU', 'a5', timebox=[00000401L,00001031L], DATASETTYPE='varamma_t3', AXE='latitude', ubox=[-30.,+40.,-30.,45.]
;
; :History:
;
;  $Id: hovmuller.pro 215 2011-04-26 10:33:10Z pinsard $
;
; - fplod 20110426T083803Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * usage of PROJECT*
;
; - fplod 2009-05-15T08:30:11Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * days on X axis labels if less than 2 months in timebox for AMSU climatology plot
;
; - fplod 2009-05-14T14:27:07Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * remove iyear parameter
;   * add TIMEBOX keyword but !! not yet ok for multiple years queries
;
; - fplod 2008-12-23T13:49:03Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add latitude and longitude boundaries in keywords (UBOX)
;
; - fplod 2008-08-14T15:31:11Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * j'ajoute la possibilit de travailler avec les fichiers de climato
;     en ajoutant un motcle datasettype (ceux qui peut permettre mme pour
;     OLR par exemple de travailler soit avec les fichiers splits soit avec
;     le fichiers original ... enfin c'est l'ide.
;   * j'ai compris que 1) il faut /timestep pour AMSU (parce l'axe des temps
;     ne fait pas partie de ceux gers par ncdf_gettime) 2) qu'il y a un gros
;     avec les longitudes OLR
;
; - fplod 2008-08-13T08:02:19Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * replace hovmuller_latitude by hovmuller
;   * add AXE keyword
;   * change terminology of latitude image file hov by hovy
;   * check parameters (type and value)
;   * parametrization of xaxisname, yaxisname and timevar
;
; - fplod 2008-08-12T14:17:14Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add _EXTRA keyword
;   * change format of colorbar f5.1 to I3.3, 1/10th is useless in legend and
;     I rather like have a *big* font than a dot.
;   * add OVERWRITE keyword
;   * add NOSAVE keyword
;   * subtitle = '' to avoid text between plot and color bar
;   * usage of _forout
;
; - fplod 2008-08-05T09:59:15Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * change font
;
; - fplod 2008-07-31T12:59:17Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * Start to add OLR dataset
;   * add dataset parameter
;
; - fplod 20080718
;
;   * extract from ananewvaramma3.pro 20080718 :
;
;::
;
;     hovmuller latitude
;     canal='a7'
;     mois=['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec']
;     mo_lon=[31,28,31,30,31,30,31,31,30,31,30,31]
;
;     imo=4 &im1=10  ; no du mois
;     file='stagiaire/'+canal+'.an2006.nc'
;     initncdf, file, xaxisname = 'xlon', yaxisname = 'ylat'
;     domdef,-10,5,-30,45  ;domdef,0,5,-30,45
;     j1=total(mo_lon(0:imo-2)) & J2=total(mo_lon(0:im1-1))
;     data=read_ncdf('moyenne_tb', j1,j2,/timestep,timevar = 'jours', file = file)
;     time=julday(imo,1,2006)+lindgen(jpt)  ; redefinition axe temps
;     pltt,window=0, data, 'yt',title='latitude - time '+canal;,min=250,max=295
;     saveimage, 'sorties/'+canal+'20060410-hov-10-5.png',/png ;capture d'ecran
;
;
; :Version:
;  $Id: hovmuller.pro 215 2011-04-26 10:33:10Z pinsard $
;
;-
pro hovmuller $
             , dataset, canal $
             , TIMEBOX=timebox $
             , DATASETTYPE=datasettype $
             , AXE=axe $
             , UBOX=ubox $
             , OVERWRITE= overwrite $
             , NOSAVE = nosave $
             , _EXTRA=extra
;
compile_opt idl2, strictarrsubs
;
@cm_4cal
@cm_project
;
; check required and optional parameters
nparam = N_PARAMS()
IF (nparam LT 2) THEN BEGIN
 ras = report('Incorrect number of arguments.')
 RETURN
ENDIF
;
IF size(dataset, /type) NE 7 THEN BEGIN
 ras = report('dataset must be a string')
 help,dataset
 RETURN
ENDIF
;
IF size(canal, /type) NE 7 THEN BEGIN
 ras = report('canal must be a string')
 help,canal
 RETURN
ENDIF
;
CASE dataset OF
 'AMSU' : BEGIN
          END
 'OLR' : BEGIN
          END
 ELSE  : BEGIN
  msg = 'eee : invalid dataset parameter = ' + dataset
  ras = report(msg)
  msg = 'eee : dataset must be AMSU or OLR'
  ras = report(msg)
  RETURN
         END
 ENDCASE

; check input parameters
 IF (dataset EQ 'AMSU') THEN BEGIN
  CASE strmid(canal,0,1) OF
  'a' : BEGIN
   CASE strmid(canal,1) OF
   '1' :
   '2' :
   '3' :
   '4' :
   '5' :
   '6' :
   '7' :
   '8' :
   '9' :
   '15' : BEGIN
    msg = 'iii : valid canal parameter = ' + canal
    ras = report(msg)
        END
   ELSE : BEGIN
    msg = 'eee : invalid canal parameter = ' + canal
    ras = report(msg)
    msg = 'eee : canal must be a1, a2, a3, a4, a5, a6, a7, a8, a9 or a15'
    ras = report(msg)
    RETURN
          END
   ENDCASE
        END
  'b' : BEGIN
   CASE strmid(canal,1) OF
   '1' :
   '2' :
   '3' :
   '4' :
   '5' : BEGIN
    msg = 'iii : valid canal parameter = ' + canal
    ras = report(msg)
        END
   ELSE : BEGIN
    msg = 'eee : invalid canal parameter = ' + canal
    ras = report(msg)
    msg = 'eee : canal must be b1, b2, b3, b4 or b15'
    ras = report(msg)
    RETURN
          END
   ENDCASE
        END
  ELSE  : BEGIN
   msg = 'eee : invalid canal parameter = ' + canal
   ras = report(msg)
   msg = 'eee : canal must be start with a or b'
   ras = report(msg)
   RETURN
          END
  ENDCASE
 ENDIF
;
IF (keyword_set(DATASETTYPE)) THEN BEGIN
 datasettype = datasettype
ENDIF ELSE BEGIN
 CASE dataset OF
  'AMSU' : BEGIN
    datasettype = 'varamma_t2'
           END
  'OLR' : BEGIN
    datasettype = 'olr_t2'
          END
 ENDCASE
ENDELSE

; ++ validation de datasettype

IF (keyword_set(AXE)) THEN BEGIN
 axe = axe
ENDIF ELSE BEGIN
 axe='latitude'
ENDELSE

CASE axe OF
 'latitude' :
 'longitude' :  BEGIN
   msg = 'iii : valid axe keyword = ' + axe
   ras = report(msg)
                END
 ELSE : BEGIN
  msg = 'eee : invalid axe keyword = ' + axe
  ras = report(msg)
  msg = 'eee : axe must be latitude or longitude'
  ras = report(msg)
  RETURN
        END
ENDCASE
;
IF (keyword_set(UBOX)) THEN BEGIN
 IF (N_ELEMENTS(ubox) NE 4) THEN BEGIN
  msg = 'eee : ubox must be a 1D array of 4 items'
  ras = report(msg)
  RETURN
 ENDIF ELSE BEGIN
  ulon1 = ubox[0]
  ulon2 = ubox[1]
  ulat1 = ubox[2]
  ulat2 = ubox[3]
 ; ++ check lat and lon validity
 ENDELSE
ENDIF ELSE BEGIN
 msg = 'eee : no box user defined'
 ras = report(msg)
 RETURN
ENDELSE

IF (keyword_set(TIMEBOX)) THEN BEGIN
 IF (N_ELEMENTS(timebox) NE 2) THEN BEGIN
  msg = 'eee : timebox must be a 1D array of 2 long integers'
  ras = report(msg)
  RETURN
 ENDIF ELSE BEGIN
  yyyymmdd1 = timebox[0]
  yyyymmdd2 = timebox[1]
 ; ++ check datemin and datemax validity
  tmp=date2jul(yyyymmdd1,month=imm1,day=idd1,year=iyyyy1)
  tmp=date2jul(yyyymmdd2,month=imm2,day=idd2,year=iyyyy2)
  IF (yyyymmdd1 GE yyyymmdd2) THEN BEGIN
   msg = 'eee : yyyymmdd1 must be smaller than yyyymmdd2'
   ras = report(msg)
   RETURN
  ENDIF
  IF (iyyyy1 NE iyyyy2) THEN BEGIN
   msg = 'eee : year 1 must be equal to year 2 (will be changed !!) now : sorry'
   ras = report(msg)
   RETURN
  ENDIF
  ; ++ seulement si pas climato
  IF (datasettype NE 'varamma_t3') THEN BEGIN
   IF (yyyymmdd1 LT 20000101L) OR (yyyymmdd1 GT 20071231L) THEN BEGIN
    msg = 'eee : yyyymmdd1 must be between 20000101L and 20071231L'
    ras = report(msg)
    RETURN
   ENDIF
   IF (yyyymmdd2 LT 20000101L) OR (yyyymmdd2 GT 20071231L) THEN BEGIN
    msg = 'eee : yyyymmdd2 must be between 20000101L and 20071231L'
    ras = report(msg)
    RETURN
   ENDIF
  ENDIF
 ENDELSE
ENDIF ELSE BEGIN
 msg = 'eee : no timebox user defined'
 ras = report(msg)
 RETURN
ENDELSE

IF (keyword_set(overwrite)) THEN BEGIN
 overwrite = 1
ENDIF ELSE BEGIN
 overwrite = 0
ENDELSE
;
IF (keyword_set(nosave)) THEN BEGIN
 save = 0
ENDIF ELSE BEGIN
 save = 1
ENDELSE
;
; check for input file
;
; test if ${PROJECT_ID} defined
 CASE project_id_env OF
  ''  :  BEGIN
   msg = 'eee : ${PROJECT_ID} is not defined'
   ras = report(msg)
   RETURN
         END
  ELSE: BEGIN
   msg = 'iii : ${PROJECT_ID} is ' + project_id_env
   ras = report(msg)
        END
 ENDCASE
;
iodirin = isadirectory(project_id_env)
;
; existence and protection of iodirin
IF (FILE_TEST(iodirin, /DIRECTORY, /EXECUTABLE, /READ) EQ 0) THEN BEGIN
    msg = 'eee : the directory' + iodirin  + ' is not accessible.'
    ras = report(msg)
    STOP
ENDIF
;
; build input and output filenames
; define field to be plot (field)
; define the title of the plot (title)
; define the interval of each color level (int)
; for hovmuller latitude and longitude
; ++for hovmuller longitude
CASE axe OF
 'latitude' : BEGIN
  plottype = 'yt'
  plotname='-hovy-'
  ccoord1=string(abs(ulon1),format='(I3.3)')
  ccoord2=string(abs(ulon2),format='(I3.3)')
              END
 'longitude' :  BEGIN
  plottype = 'xt'
  plotname='-hovx-'
  ccoord1=string(abs(ulat1),format='(I3.3)')
  ccoord2=string(abs(ulat2),format='(I3.3)')
                END
ENDCASE
;
CASE dataset OF
 'AMSU' : BEGIN
   CASE datasettype OF
   'varamma_t2' : BEGIN
    ;++ loop on years between iyyyy1 and iyyyy2
    filename_in=canal+'.an'+string(iyyyy1,format='(I4.4)')+'.nc'
    filename_out=canal+string(yyyymmdd1,format='(I8.8)')+ $
    '-'+ $
    string(yyyymmdd2,format='(I8.8)')+ $
    plotname + $
    ccoord1 + $
    '-'+ $
    ccoord2 + $
    '.png'
    title=axe + ' - time '+ dataset + ' ' + canal + ' ' $
          + string(yyyymmdd1,format='(I8.8)') $
          + ' ' $
          + string(yyyymmdd2,format='(I8.8)')

                END
   'varamma_t3' : BEGIN
    filename_in=canal+'.climato.nc'
    filename_out=canal+'.climato' + $
    plotname + $
    ccoord1 + $
    '-'+ $
    ccoord2 + $
    '.png'
    title=axe + ' - time '+ dataset + ' ' + canal + ' climatology' $
          + string(yyyymmdd1,format='(I8.8)') $
          + ' ' $
          + string(yyyymmdd2,format='(I8.8)')
    ; labels on X axis are months if more than 1 month is asked
    ; on climatology plot, else labels on X axis are days.
    IF (imm1 NE imm2) THEN BEGIN
     date_format='%M'
    ENDIF ELSE BEGIN
     date_format='%D'
    ENDELSE
               END
   ENDCASE
   xaxisname = 'xlon'
   yaxisname = 'ylat'
   timevar = 'jours'
   field='moyenne_tb'
   int = .5
          END
 'OLR' : BEGIN
   CASE datasettype OF
   'olr_t2' : BEGIN
    ; ++ multiple years
    filename_in='olr.day.mean_'+string(iyyyy1,format='(I4.4)')+'_ng.nc'
    filename_out='olr.day.mean_'+string(yyyymmdd1,format='(I8.8)')+ $
    '-'+ $
    string(yyyymmdd2,format='(I8.8)')+ $
    plotname + $
    ccoord1 + $
    '-'+ $
    ccoord2 + $
    '.png'
    title=axe + ' - time '+ dataset + ' ' + string(yyyymmdd1,format='(I8.8)') $
          + ' ' + string(yyyymmdd2,format='(I8.8)')
               END
   'olr_t3' : BEGIN
    filename_in='olr.day.mean_climato_ng.nc'
    filename_out='olr.day.mean_climato_'+ $
    plotname + $
    ccoord1 + $
    '-'+ $
    ccoord2 + $
    '.png'
    title=axe + ' - time '+ dataset + ' climatology'
                END
   ENDCASE
   xaxisname = 'lon'
   yaxisname = 'lat'
   timevar = 'time'
   field='olr'
   int = 8
          END
 ELSE  : BEGIN
  msg = 'eee : invalid dataset parameter = ' + dataset
  ras = report(msg)
  msg = 'eee : dataset must be AMSU or OLR'
  ras = report(msg)
  RETURN
         END
 ENDCASE
;
CASE dataset OF
 'AMSU' : BEGIN
     iodirin = iodirin + '/AMSU'
          END
 'OLR' : BEGIN
     iodirin = iodirin + '/OLR'
          END
 ENDCASE
;
; check if this file exists
 fullfilename_in = isafile(iodirin + filename_in, NEW=0, /MUST_EXIST)
 IF fullfilename_in[0] EQ '' THEN BEGIN
  msg = 'eee : the file ' + fullfilename_in + ' was not found.'
  ras = report(msg)
  RETURN
 ENDIF
;
IF (save) THEN BEGIN
 fullfilename_out=forout(filename_out, OVERWRITE=overwrite)
 IF (fullfilename_out EQ -1) THEN BEGIN
  RETURN
 ENDIF
ENDIF
;
initncdf, fullfilename_in[0], xaxisname = xaxisname , yaxisname = yaxisname
msg = 'iii : initcdf with ' + fullfilename_in[0]
ras = report(msg)
;
; reduce geographic domain
domdef,ulon1,ulon2,ulat1,ulat2
;
CASE dataset OF
 'AMSU' : BEGIN
; compute timesteps because time( days since 2000-01-01) in this dataset is not recognize by
; ncdf_gettime.pro
; ++ multiple years
timestep1=julday(imm1,idd1,iyyyy1) - julday(01,01,iyyyy1) + 1
timestep2=julday(imm2,idd2,iyyyy2) - julday(01,01,iyyyy2) + 1
          END
 'OLR' : BEGIN
          END
ENDCASE
;
; read data to be plot
CASE dataset OF
 'AMSU' : BEGIN
data=read_ncdf(field, timestep1, timestep2, /timestep,timevar = timevar, file = fullfilename_in[0])
          END
 'OLR' : BEGIN
data=read_ncdf(field, yyyymmdd1, yyyymmdd2, timevar = timevar, file = fullfilename_in[0])
          END
ENDCASE
;
; redefinition axe temps ++ CASE DATASET
time=julday(imm1,idd1,iyyyy1)+lindgen(jpt)
;
; define font
!P.FONT = 0
;DEVICE, SET_FONT = "-adobe-helvetica-medium-r-normal--17-120-100-100-p-88-iso8859-1"
;
; plot hovmuller diagram
; with no contour (/nocontour)
; using color palette 64 (lct=64)
; maximizing the size of the plot in the window (/rempli)
; subtitle = '' to avoid text between plot and color bar
;
 pltt, data, plottype, $
 title=title,/nocontour, int = int, format='(I3.3)', $
 lct = 64, /rempli, $
 subtitle=' ', $
 DATE_FORMAT=date_format, $
 _EXTRA=extra
;
; save an image file if asked
IF (save) THEN BEGIN
 saveimage, fullfilename_out,/png
ENDIF

END
